pub enum SendBitswapMessageError {
NoConnection,
QueueFull,
}Expand description
Error potentially returned by ChainNetwork::bitswap_send_message.
Variants
NoConnection
There is no open outbound Bitswap substream with the given peer.
QueueFull
Queue of Bitswap messages with that peer is full.