ConfigChain

Struct ConfigChain 

pub struct ConfigChain {
    pub log_name: String,
    pub num_out_slots: usize,
    pub genesis_block_hash: [u8; 32],
    pub best_block: (u64, [u8; 32]),
    pub fork_id: Option<String>,
    pub block_number_bytes: usize,
    pub grandpa_protocol_finalized_block_height: Option<u64>,
    pub statement_protocol_config: Option<StatementProtocolConfig>,
}
See NetworkService::add_chain.

Note that this configuration is intentionally missing a field containing the bootstrap nodes of the chain. Bootstrap nodes are supposed to be added afterwards by calling NetworkServiceChain::discover.

Fields

log_name: String

Name of the chain, for logging purposes.

num_out_slots: usize

Number of “out slots” of this chain. We establish simultaneously gossip substreams up to this number of peers.

genesis_block_hash: [u8; 32]

Hash of the genesis block of the chain. Sent to other nodes in order to determine whether the chains match.

Note: Be aware that this must be the genesis block, not any block known to be in the chain.

best_block: (u64, [u8; 32])

Number and hash of the current best block. Can later be updated with NetworkServiceChain::set_local_best_block.

fork_id: Option<String>

Optional identifier to insert into the networking protocol names. Used to differentiate between chains with the same genesis hash.

block_number_bytes: usize

Number of bytes of the block number in the networking protocol.

grandpa_protocol_finalized_block_height: Option<u64>

Must be Some if and only if the chain uses the GrandPa networking protocol. Contains the number of the finalized block at the time of the initialization.

statement_protocol_config: Option<StatementProtocolConfig>

If Some, enables the statement store protocol.