Struct smoldot_light::Client
source · pub struct Client<TPlat: PlatformRef, TChain = ()> { /* private fields */ }Expand description
Holds a list of chains, connections, and JSON-RPC services.
Implementations
sourceimpl<TPlat: PlatformRef, TChain> Client<TPlat, TChain>
impl<TPlat: PlatformRef, TChain> Client<TPlat, TChain>
sourcepub fn add_chain(
&mut self,
config: AddChainConfig<'_, TChain, impl Iterator<Item = ChainId>>
) -> Result<AddChainSuccess, AddChainError>
pub fn add_chain( &mut self, config: AddChainConfig<'_, TChain, impl Iterator<Item = ChainId>> ) -> Result<AddChainSuccess, AddChainError>
Adds a new chain to the list of chains smoldot tries to synchronize.
Returns an error in case something is wrong with the configuration.
sourcepub fn remove_chain(&mut self, id: ChainId) -> TChain
pub fn remove_chain(&mut self, id: ChainId) -> TChain
Removes the chain from smoldot. This instantaneously and silently cancels all on-going JSON-RPC requests and subscriptions.
The provided ChainId is now considered dead. Be aware that this same ChainId might
later be reused if Client::add_chain is called again.
While from the API perspective it will look like the chain no longer exists, calling this function will not actually immediately disconnect from the given chain if it is still used as the relay chain of a parachain.
If the JsonRpcResponses object that was returned when adding the chain is still alive,
JsonRpcResponses::next will now return None.
sourcepub fn json_rpc_request(
&mut self,
json_rpc_request: impl Into<String>,
chain_id: ChainId
) -> Result<(), HandleRpcError>
pub fn json_rpc_request( &mut self, json_rpc_request: impl Into<String>, chain_id: ChainId ) -> Result<(), HandleRpcError>
Enqueues a JSON-RPC request towards the given chain.
Since most JSON-RPC requests can only be answered asynchronously, the request is only queued and will be decoded and processed later.
Returns an error if the number of requests that have been sent but whose answer hasn’t been
pulled with JsonRpcResponses::next is superior or equal to the value that was passed
through AddChainConfigJsonRpc::Enabled::max_pending_requests. In that situation, the
API user is encouraged to stop sending requests and start pulling answers with
JsonRpcResponses::next.
Passing u32::max_value() to AddChainConfigJsonRpc::Enabled::max_pending_requests is
a good way to avoid errors here, but this should only be done if the JSON-RPC client is
trusted.
Also returns an error if the request could not be parsed as a valid JSON-RPC request, as in that situation smoldot is unable to send back a corresponding JSON-RPC error message.
Panic
Panics if the ChainId is invalid, or if AddChainConfig::json_rpc was
AddChainConfigJsonRpc::Disabled when adding the chain.